@@ -1,5 +1,5 @@
 package Net::Easypost;
-$Net::Easypost::VERSION = '0.13';
+$Net::Easypost::VERSION = '0.14';
 use Data::Dumper;
 use Carp qw(croak);
 use Hash::Merge::Simple qw(merge);
@@ -110,7 +110,7 @@ Net::Easypost - Perl client for the Easypost web service
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -123,6 +123,7 @@ version 0.13
       state   => 'VA',
       zip     => '22902',
       phone   => '(434)555-5555',
+      country => 'US',
    );
 
    my $from = Net::Easypost::Address->new(
@@ -132,6 +133,7 @@ version 0.13
       street1 => '310 Granelli Ave',
       state   => 'CA',
       zip     => '94019',
+      country => 'US',
    );
 
    my $parcel = Net::Easypost::Parcel->new(
@@ -156,13 +158,11 @@ version 0.13
 
 =head1 OVERVIEW
 
-This is a Perl client for the postage API at L<Easypost|https://www.geteasypost.com>. Consider this
+This is a Perl client for the postage API at L<Easypost|https://www.easypost.com/docs/api>. Consider this
 API at beta quality mostly because some of these library calls have an inconsistent input
 parameter interface which I'm not super happy about. Still, there's enough here to get
 meaningful work done, and any future changes will be fairly cosmetic.
 
-At this time, Easypost only supports United States based addresses.
-
 Please note! B<All API errors are fatal via croak>. If you need to catch errors more gracefully, I
 recommend using L<Try::Tiny> in your implementation.
 
@@ -196,6 +196,8 @@ This method attempts to validate an address. This call expects to take the same
 
 =item * zip
 
+=item * country
+
 =back
 
 You may omit some of these attributes like city, state if you supply a zip, or
@@ -206,6 +208,10 @@ This call returns a new L<Net::Easypost::Address> object.
 Along with the validated address, the C<phone> and C<name> fields will be
 copied from the input parameters, if they're set.
 
+The verification works only for addresses in US. If you pass a country
+other than US (the default), a warning will be issued, but the
+L<Net::Easypost::Address> object will be returned.
+
 =head2 get_rates
 
 This method will get postage rates between two zip codes. It takes the following input parameters:
@@ -263,7 +269,7 @@ L<https://github.com/mrallen1/Net-Easypost/issues>
 
 =over
 
-=item * L<Easypost API docs|https://www.geteasypost.com/api>
+=item * L<Easypost API docs|https://www.easypost.com/docs/api>
 
 =back
 
