@@ -1,6 +1,6 @@
 package Net::Easypost::Address;
-$Net::Easypost::Address::VERSION = '0.13';
-use Carp qw(croak);
+$Net::Easypost::Address::VERSION = '0.14';
+use Carp qw(croak carp);
 use Moo;
 use Scalar::Util;
 use overload
@@ -49,7 +49,14 @@ has name => (
 );
 
 
-sub _build_fieldnames { [qw(name street1 street2 city state zip phone)] }
+has country => (
+                is => 'rw',
+                default => sub { 'US' },
+               );
+
+
+
+sub _build_fieldnames { [qw(name street1 street2 city state zip phone country)] }
 
 
 sub _build_role { 'address' }
@@ -94,8 +101,10 @@ sub merge {
 
 sub verify {
     my $self = shift;
-    use Data::Dumper;
-
+    if ($self->country ne 'US') {
+        carp "Verifying addresses outside US is not supported";
+        return $self;
+    }
     my $verify_response =
        $self->requester->get( $self->operation . '/' . $self->id . '/verify' );
 
@@ -124,7 +133,7 @@ Net::Easypost::Address - Class to represent an Easypost address
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 ATTRIBUTES
 
@@ -157,6 +166,10 @@ require a sender phone number.
 
 A name associated with this address.
 
+=head2 country
+
+The country code. Default to US.
+
 =head1 METHODS
 
 =head2 _build_fieldnames
@@ -188,7 +201,10 @@ into B<this> object. This method only merges fields that are defined on the othe
 =head2 verify
 
 This method takes a L<Net::Easypost::Address> object and verifies its underlying
-address
+address.
+
+If a non-US address is asked for verification, a warning will be
+emitted and the object itself will be returned.
 
 =head1 AUTHOR
 
